@@ -4,17 +4,20 @@ from .urlconf import ModuleURLResolver, frontend_url
 from .registry import modules
 
 
-__all__ = [
+__all__ = (
     'ModuleURLResolver', 'frontend_url', 'modules'
-]
+)
 
 default_app_config = 'material.frontend.apps.MaterialFrontendConfig'
 
 
 if getattr(settings, 'MATERIAL_FRONTEND_AUTOREGISTER', True):
     # Register middleware
-    if 'material.frontend.middleware.SmoothNavigationMiddleware' not in settings.MIDDLEWARE_CLASSES:
-        settings.MIDDLEWARE_CLASSES += ('material.frontend.middleware.SmoothNavigationMiddleware',)
+    if 'material.frontend.middleware.SmoothNavigationMiddleware' not in settings.MIDDLEWARE:
+        settings.MIDDLEWARE += (
+            'material.frontend.middleware.SmoothNavigationMiddleware',
+            'material.frontend.middleware.TurbolinksMiddleware',
+        )
 
     # Context processors
     for engine in settings.TEMPLATES:
