@@ -1,7 +1,11 @@
+from __future__ import unicode_literals
+
 from django.contrib.auth import get_permission_codename
-from django.core.urlresolvers import reverse
+from django.urls import reverse
+from django.utils.translation import ugettext_lazy as _
 from django.views import generic
 
+from ...compat import _
 from .mixins import MessageUserMixin, ModelViewMixin
 
 
@@ -34,4 +38,4 @@ class UpdateModelView(MessageUserMixin, ModelViewMixin, generic.UpdateView):
         return super(ModelViewMixin, self).get_success_url()
 
     def message_user(self):
-        self.success('The {name} "{link}" was changed successfully.')
+        self.success(_('The {name} "{link}" was changed successfully.'))
